# coding: utf-8

"""
    Vayu API

    The Vayu API is a RESTful API that allows you to submit events for processing and storage & manage billing related entities.           The API is secured using the Bearer Authentication scheme with JWT tokens.           To obtain a JWT token, please contact Vayu at team@withvayu.com

    The version of the OpenAPI document: 1.0.0
    Contact: dev@withvayu.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AggregationOperator(str, Enum):
    """
    The aggregation method defines how the events should be summed to represent a usage value.
    """

    """
    allowed enum values
    """
    COUNT = 'Count'
    SUM = 'Sum'
    DISTINCT = 'Distinct'
    MAX = 'Max'
    MIN = 'Min'
    AVERAGE = 'Average'
    FIRST = 'First'
    LAST = 'Last'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AggregationOperator from a JSON string"""
        return cls(json.loads(json_str))


